@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="en">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
 <context>
     <name>DUMountManager</name>
     <message>
@@ -118,4 +116,4 @@
         <translation>Stop</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
