@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     yanghao<yanghao@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             yanghao<yanghao@uniontech.com>
- *             hujianzhong<hujianzhong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dfileviewhelper.h"
 #include "dfmglobal.h"
@@ -671,11 +652,14 @@ void DFileViewHelper::handleMenu(QMenu *menu)
 
     tag_widget->setCheckedColorList(colors);
 
-    connect(tag_widget, &DTagActionWidget::hoverColorChanged, menu, [tag_widget](const QColor & color) {
+    connect(tag_widget, &DTagActionWidget::hoverColorChanged, menu, [tag_widget, colors](const QColor & color) {
         if (color.isValid()) {
             const QString &tag_name = TagManager::instance()->getTagNameThroughColor(color);
 
-            tag_widget->setToolTipText(tr("Add tag \"%1\"").arg(tag_name));
+            if (colors.contains(color))
+                tag_widget->setToolTipText(tr("Remove tag \"%1\"").arg(tag_name));
+            else
+                tag_widget->setToolTipText(tr("Add tag \"%1\"").arg(tag_name));
         } else {
             tag_widget->clearToolTipText();
         }
