@@ -942,7 +942,9 @@ void DFMSideBar::initDeviceConnection()
 
         if (this->findItem(url) == -1) {
             auto r = std::upper_bound(devitems.begin(), devitems.end(), url,
-            [](const DUrl & a, const DUrl & b) {
+            [&url](const DUrl & a, const DUrl & b) {
+                if(FileUtils::isSmbHostOnly(url))
+                    return false;
                 DAbstractFileInfoPointer fia = fileService->createFileInfo(nullptr, a);
                 DAbstractFileInfoPointer fib = fileService->createFileInfo(nullptr, b);
                 return DFMRootFileInfo::typeCompare(fia, fib);
@@ -1247,7 +1249,6 @@ void DFMSideBar::insertItem(int index, DFMSideBarItem *item, const QString &grou
         return;
     }
     item->setGroupName(groupName);
-    qInfo()<<"11 item url = "<<item->url();
     m_sidebarModel->insertRow(index, item);
 }
 
