@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2019 Deepin Technology Co., Ltd.
- *
- * Author:     Mike Chen <kegechen@gmail.com>
- *
- * Maintainer: Mike Chen <chenke_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef DFMTAGWIDGET_H
 #define DFMTAGWIDGET_H
 #include "dfmglobal.h"
@@ -50,6 +34,8 @@ public:
 protected:
     void initUi();
     void initConnection();
+    void updateCrumbsColor(const QMap<QString, QColor> &tagsColor);
+    QMap<QString, QColor> tagsColor(const QStringList &tagList);
 private:
     QScopedPointer<DFMTagWidgetPrivate> d_private;
     Q_DECLARE_PRIVATE_D(d_private, DFMTagWidget)
