@@ -1,24 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     wangchunlin<wangchunlin@uniontech.com>
- *
- * Maintainer: wangchunlin<wangchunlin@uniontech.com>
- *             xinglinkun<xinglinkun@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "wallpaperitem.h"
 #include "constants.h"
 #include "thumbnailmanager.h"
@@ -183,6 +166,22 @@ QPushButton *WallpaperItem::addButton(const QString &id, const QString &text, co
     return button;
 }
 
+/*!
+ * \brief WallpaperItem::setEntranceIconOfSettings, add Settings entrance icon for custom screensavers
+ * \param id, the name of custom screensaver with custom configuration
+ */
+void WallpaperItem::setEntranceIconOfSettings(const QString &id)
+{
+    EditLabel *editLabel = new EditLabel(m_wrapper);
+    QPixmap pmap(":/images/edit.svg");
+    editLabel->setPixmap(pmap);
+    editLabel->move(m_wrapper->width()-pmap.width(), 0);
+
+    connect(editLabel, &EditLabel::editLabelClicked, this, [this, id] {
+        emit buttonClicked(id);
+    });
+}
+
 void WallpaperItem::slideUp()
 {
     if (m_wrapper->y() < 0 && m_downAnim->state() == QAbstractAnimation::Stopped)
