@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include <gtest/gtest.h>
 #include <gmock/gmock-matchers.h>
 #include <QThread>
@@ -34,7 +38,7 @@
 #include "view/desktopitemdelegate.h"
 #include "../dde-desktop/desktop.h"
 #include "../dde-desktop/desktop.cpp"
-#include "dfileviewhelper.h"
+#include "canvasviewhelper.h"
 #include "addr_pri.h"
 #include "stub.h"
 #include "diconitemdelegate.h"
@@ -435,7 +439,7 @@ TEST_F(CanvasGridViewTest, CanvasGridViewTest_showNormalMenu){
         stubRet = 1;
         return (QAction*)nullptr;
     });
-    auto exec_foo = (QAction* (DFileMenu::*)())&DFileMenu::exec;
+    auto exec_foo = (QAction* (DFileMenu::*)())(&DFileMenu::exec);
     st.set(exec_foo, exec_stub);
 
     auto noneWld = (bool(*)())([](){return false;});
@@ -464,7 +468,7 @@ TEST_F(CanvasGridViewTest, CanvasGridViewTest_showEmptyAreaMenu){
         stubRet = 1;
         return (QAction*)nullptr;
     });
-    auto exec_foo = (QAction* (DFileMenu::*)())&DFileMenu::exec;
+    auto exec_foo = (QAction* (DFileMenu::*)())(&DFileMenu::exec);
     st.set(exec_foo, exec_stub);
 
     auto noneWld = (bool(*)())([](){return false;});
@@ -1205,7 +1209,6 @@ TEST_F(CanvasGridViewTest, CanvasGridViewTest_lastIndex)
     EXPECT_TRUE(theSameOne);
 }
 
-
 TEST_F(CanvasGridViewTest, Test_CanvasGridViewTest_select){
     ASSERT_NE(m_canvasGridView, nullptr);
     m_canvasGridView->selectionModel()->clearSelection();
@@ -1217,6 +1220,7 @@ TEST_F(CanvasGridViewTest, Test_CanvasGridViewTest_select){
     auto expectValue = count1 != count2;
     EXPECT_TRUE(expectValue);
 }
+
 #endif
 TEST_F(CanvasGridViewTest, CanvasGridViewTest_setSelection){
     ASSERT_NE(m_canvasGridView, nullptr);
@@ -1496,7 +1500,6 @@ TEST_F(CanvasGridViewTest, CanvasGridViewTest_delayAutoMerge_autoMergeSelectedUr
     delete model;
     model = nullptr;
 }
-
 //new
 
 TEST_F(CanvasGridViewTest, canvasGridViewTest_startDrag)
@@ -1678,7 +1681,6 @@ TEST_F(CanvasGridViewTest, canvasGridViewTest_decreaseIcon)
     loop.exec();
 }
 
-
 TEST_F(CanvasGridViewTest, canvasGridViewTest_gridat)
 {
     QPoint pos(300, 200);
@@ -1711,7 +1713,6 @@ TEST_F(CanvasGridViewTest, canvasGridViewTest_syncIconLevel)
     EXPECT_EQ(level, m_canvasGridView->itemDelegate()->iconSizeLevel());
 }
 
-
 TEST_F(CanvasGridViewTest, canvasGridViewTest_openUrls)
 {
     qApp->processEvents();
@@ -1887,7 +1888,7 @@ TEST_F(CanvasGridViewTest, test_DumpPos)
 
     QString temp = m_canvasGridView->DumpPos(0, 0);
     EXPECT_TRUE(!temp.isEmpty());
-    m_canvasGridView->Refresh();
+    m_canvasGridView->Refresh(true);
 }
 
 TEST_F(CanvasGridViewTest, test_currentCursorFile)
@@ -2363,6 +2364,67 @@ TEST_F(CanvasGridViewTest, CanvasGridViewTest_setSelection_shiftAndArrowKeys)
     }
 }
 
+TEST_F(CanvasGridViewTest, Test_CanvasGridViewTest_refresh)
+{
+    ASSERT_NE(m_canvasGridView, nullptr);
+    stub_ext::StubExt stub;
+    bool model = false;
+    stub.set_lamda(&DFileSystemModel::refresh, [&model](){
+        model = true;
+    });
+    bool flash = false;
+    stub.set_lamda(VADDR(CanvasViewHelper,viewFlicker), [&flash](){
+        flash = true;
+    });
+
+    m_canvasGridView->Refresh(true);
+    EXPECT_TRUE(model);
+    EXPECT_FALSE(flash);
+
+    model = false;
+    flash = false;
+    m_canvasGridView->Refresh(false);
+    EXPECT_TRUE(flash);
+    EXPECT_FALSE(model);
+}
+
+TEST(CanvasGridView, inputMethodQuery)
+{
+    CanvasGridView view("");
+    stub_ext::StubExt stub;
+    QSize size(123, 456);
+    stub.set_lamda(&CanvasGridView::iconSize, [size](){
+        return size;
+    });
+
+    auto rect = view.inputMethodQuery(Qt::ImCursorRectangle).toRect();
+    EXPECT_EQ(rect.size(), size);
+}
+
+TEST(CanvasGridView, focusInEvent_inputMethod)
+{
+    CanvasGridView view("");
+    view.setAttribute(Qt::WA_InputMethodEnabled, false);
+    view.setCurrentIndex(QModelIndex());
+
+    ASSERT_FALSE(view.testAttribute(Qt::WA_InputMethodEnabled));
+    ASSERT_FALSE(view.currentIndex().isValid());
+    QFocusEvent e(QEvent::FocusIn);
+    view.focusInEvent(&e);
+
+    EXPECT_TRUE(view.testAttribute(Qt::WA_InputMethodEnabled));
+}
+
+TEST(CanvasGridView, currentChanged_inputMethod)
+{
+    CanvasGridView view("");
+    view.setAttribute(Qt::WA_InputMethodEnabled, false);
+    ASSERT_FALSE(view.testAttribute(Qt::WA_InputMethodEnabled));
+
+    view.currentChanged(QModelIndex(), QModelIndex());
+    EXPECT_TRUE(view.testAttribute(Qt::WA_InputMethodEnabled));
+}
+
 TEST(CanvasGridViewTest_end, endTest)
 {
     auto path = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
