@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     dengkeyun<dengkeyun@uniontech.com>
- *
- * Maintainer: max-lv<lvwujun@uniontech.com>
- *             xushitong<xushitong@uniontech.com>
- *             zhangsheng<zhangsheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "app/define.h"
 #include "interfaces/drootfilemanager.h"
@@ -28,6 +9,7 @@
 #include <gtest/gtest.h>
 #include <QTimer>
 #include <QIcon>
+#include <QPluginLoader>
 
 #include "stub.h"
 #include "stubext.h"
@@ -37,7 +19,7 @@
 #define private public
 #define protected public
 #include "models/computermodel.h"
-
+#include "plugins/schemepluginmanager.h"
 DWIDGET_USE_NAMESPACE
 namespace {
 class TestComputerModel : public testing::Test
@@ -65,7 +47,6 @@ public:
     Stub stl;
 };
 } // namespace
-
 TEST_F(TestComputerModel, tstConstructors)
 {
     Stub stl;
@@ -82,7 +63,6 @@ TEST_F(TestComputerModel, tstConstructors)
     QObject::connect(&t, &QTimer::timeout, &loop, [&loop]{
         loop.exit();
     });
-
     DRootFileManager::instance()->startQuryRootFile();
     t.start();
     loop.exec();
